{
    "$graph": [
        {
            "class": "Workflow",
            "label": "adapter for sequence_align_and_tag",
            "doc": "Some workflow engines won't stage files in our nested structure, so parse it out here",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#sequence_data.yml/sequence_data",
                            "label": "sequence data with readgroup information",
                            "fields": [
                                {
                                    "type": "string",
                                    "name": "#sequence_data.yml/sequence_data/readgroup"
                                },
                                {
                                    "type": [
                                        {
                                            "type": "record",
                                            "name": "#sequence_data.yml/sequence_data/sequence/bam",
                                            "fields": [
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/bam/bam"
                                                }
                                            ]
                                        },
                                        {
                                            "type": "record",
                                            "name": "#sequence_data.yml/sequence_data/sequence/fastqs",
                                            "fields": [
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/fastqs/fastq1"
                                                },
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/fastqs/fastq2"
                                                }
                                            ]
                                        }
                                    ],
                                    "name": "#sequence_data.yml/sequence_data/sequence"
                                }
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimming_options.yml/trimming_options",
                            "label": "trimming adapter file and parameters",
                            "fields": [
                                {
                                    "type": "File",
                                    "doc": "Fasta file with adapters for removal that may contain N.",
                                    "name": "#trimming_options.yml/trimming_options/adapters"
                                },
                                {
                                    "type": "int",
                                    "doc": "Minimum overlap for removal without pair overlap.",
                                    "name": "#trimming_options.yml/trimming_options/min_overlap"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "doc": "bwa-indexed reference file",
                    "id": "#sequence_align_and_tag_adapter.cwl/reference"
                },
                {
                    "type": [
                        "#trimming_options.yml/trimming_options",
                        "null"
                    ],
                    "id": "#sequence_align_and_tag_adapter.cwl/trimming"
                },
                {
                    "type": "#sequence_data.yml/sequence_data",
                    "doc": "the unaligned sequence data with readgroup information",
                    "id": "#sequence_align_and_tag_adapter.cwl/unaligned"
                }
            ],
            "steps": [
                {
                    "run": "#sequence_align_and_tag.cwl",
                    "in": [
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('bam')? self.sequence.bam : null)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/bam"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('fastq1')? self.sequence.fastq1 : null)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/fastq1"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('fastq2')? self.sequence.fastq2 : null)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/fastq2"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.readgroup)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/readgroup"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/reference",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/reference"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/trimming",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/trimming"
                        }
                    ],
                    "out": [
                        "#sequence_align_and_tag_adapter.cwl/align_and_tag/aligned_bam"
                    ],
                    "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag"
                }
            ],
            "id": "#sequence_align_and_tag_adapter.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#sequence_align_and_tag_adapter.cwl/align_and_tag/aligned_bam",
                    "id": "#sequence_align_and_tag_adapter.cwl/aligned_bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "Raw sequence data to BQSR",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        },
                        {
                            "$import": "#trimming_options.yml/trimming_options"
                        }
                    ]
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#main/bqsr_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "doc": "One or more databases of known polymorphic sites used to exclude regions around known polymorphisms from analysis.",
                    "id": "#main/bqsr_known_sites"
                },
                {
                    "type": "string",
                    "default": "final",
                    "id": "#main/final_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": [
                        "#trimming_options.yml/trimming_options",
                        "null"
                    ],
                    "id": "#main/trimming"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#sequence_data.yml/sequence_data"
                    },
                    "id": "#main/unaligned"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#main/final_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/mark_duplicates_and_sort/metrics_file",
                    "id": "#main/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#main/align/unaligned"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#sequence_align_and_tag_adapter.cwl",
                    "in": [
                        {
                            "source": "#main/reference",
                            "id": "#main/align/reference"
                        },
                        {
                            "source": "#main/trimming",
                            "id": "#main/align/trimming"
                        },
                        {
                            "source": "#main/unaligned",
                            "id": "#main/align/unaligned"
                        }
                    ],
                    "out": [
                        "#main/align/aligned_bam"
                    ],
                    "id": "#main/align"
                },
                {
                    "run": "#apply_bqsr.cwl",
                    "in": [
                        {
                            "source": "#main/mark_duplicates_and_sort/sorted_bam",
                            "id": "#main/apply_bqsr/bam"
                        },
                        {
                            "source": "#main/bqsr/bqsr_table",
                            "id": "#main/apply_bqsr/bqsr_table"
                        },
                        {
                            "source": "#main/final_name",
                            "id": "#main/apply_bqsr/output_name"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/apply_bqsr/reference"
                        }
                    ],
                    "out": [
                        "#main/apply_bqsr/bqsr_bam"
                    ],
                    "id": "#main/apply_bqsr"
                },
                {
                    "run": "#bqsr.cwl",
                    "in": [
                        {
                            "source": "#main/mark_duplicates_and_sort/sorted_bam",
                            "id": "#main/bqsr/bam"
                        },
                        {
                            "source": "#main/bqsr_intervals",
                            "id": "#main/bqsr/intervals"
                        },
                        {
                            "source": "#main/bqsr_known_sites",
                            "id": "#main/bqsr/known_sites"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/bqsr/reference"
                        }
                    ],
                    "out": [
                        "#main/bqsr/bqsr_table"
                    ],
                    "id": "#main/bqsr"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#main/apply_bqsr/bqsr_bam",
                            "id": "#main/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#main/index_bam/indexed_bam"
                    ],
                    "id": "#main/index_bam"
                },
                {
                    "run": "#mark_duplicates_and_sort.cwl",
                    "in": [
                        {
                            "source": "#main/name_sort/name_sorted_bam",
                            "id": "#main/mark_duplicates_and_sort/bam"
                        }
                    ],
                    "out": [
                        "#main/mark_duplicates_and_sort/sorted_bam",
                        "#main/mark_duplicates_and_sort/metrics_file"
                    ],
                    "id": "#main/mark_duplicates_and_sort"
                },
                {
                    "run": "#merge_bams.cwl",
                    "in": [
                        {
                            "source": "#main/align/aligned_bam",
                            "id": "#main/merge/bams"
                        },
                        {
                            "source": "#main/final_name",
                            "id": "#main/merge/name"
                        }
                    ],
                    "out": [
                        "#main/merge/merged_bam"
                    ],
                    "id": "#main/merge"
                },
                {
                    "run": "#name_sort.cwl",
                    "in": [
                        {
                            "source": "#main/merge/merged_bam",
                            "id": "#main/name_sort/bam"
                        }
                    ],
                    "out": [
                        "#main/name_sort/name_sorted_bam"
                    ],
                    "id": "#main/name_sort"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "apply BQSR",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx16g",
                "ApplyBQSR"
            ],
            "arguments": [
                "-O",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_name).bam"
                },
                "--static-quantized-quals",
                "10",
                "--static-quantized-quals",
                "20",
                "--static-quantized-quals",
                "30"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#apply_bqsr.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-bqsr",
                        "position": 3
                    },
                    "id": "#apply_bqsr.cwl/bqsr_table"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "final",
                    "id": "#apply_bqsr.cwl/output_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#apply_bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name).bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#apply_bqsr.cwl/bqsr_bam"
                }
            ],
            "id": "#apply_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create BQSR table",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx16g",
                "BaseRecalibrator"
            ],
            "arguments": [
                "-O",
                {
                    "valueFrom": "$(runtime.outdir)/bqsr.table"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bqsr.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "default": [
                        "chr1",
                        "chr2",
                        "chr3",
                        "chr4",
                        "chr5",
                        "chr6",
                        "chr7",
                        "chr8",
                        "chr9",
                        "chr10",
                        "chr11",
                        "chr12",
                        "chr13",
                        "chr14",
                        "chr15",
                        "chr16",
                        "chr17",
                        "chr18",
                        "chr19",
                        "chr20",
                        "chr21",
                        "chr22"
                    ],
                    "id": "#bqsr.cwl/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--known-sites",
                            "position": 4
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bqsr.cwl/known_sites"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 2
                    },
                    "id": "#bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bqsr.table"
                    },
                    "id": "#bqsr.cwl/bqsr_table"
                }
            ],
            "id": "#bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "/usr/local/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.bam.basename).bai",
                "$(runtime.outdir)/$(inputs.bam.nameroot).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.bam; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Mark duplicates and Sort",
            "baseCommand": [
                "/bin/bash",
                "markduplicates_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 40000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/mark_duplicates-cwl:1.0.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "markduplicates_helper.sh",
                            "entry": "set -o pipefail\nset -o errexit\n\ndeclare MD_BARCODE_TAG\nif [ ! -z \"$6\" ]; then\n  MD_BARCODE_TAG=\"BARCODE_TAG=$6\"\n/usr/bin/java -Xmx16g -jar /opt/picard/picard.jar MarkDuplicates I=$1 O=/dev/stdout ASSUME_SORT_ORDER=$5 METRICS_FILE=$4 QUIET=true COMPRESSION_LEVEL=0 VALIDATION_STRINGENCY=LENIENT \"$MD_BARCODE_TAG\" | /usr/bin/sambamba sort -t $2 -m 18G -o $3 /dev/stdin\nelse\n  /usr/bin/java -Xmx16g -jar /opt/picard/picard.jar MarkDuplicates I=$1 O=/dev/stdout ASSUME_SORT_ORDER=$5 METRICS_FILE=$4 QUIET=true COMPRESSION_LEVEL=0 VALIDATION_STRINGENCY=LENIENT | /usr/bin/sambamba sort -t $2 -m 18G -o $3 /dev/stdin\nfi\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "position": 4,
                    "valueFrom": "$(inputs.bam.nameroot).mark_dups_metrics.txt"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#mark_duplicates_and_sort.cwl/bam"
                },
                {
                    "type": "string",
                    "default": "queryname",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#mark_duplicates_and_sort.cwl/input_sort_order"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "MarkedSorted.bam",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mark_duplicates_and_sort.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).mark_dups_metrics.txt"
                    },
                    "id": "#mark_duplicates_and_sort.cwl/metrics_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mark_duplicates_and_sort.cwl/sorted_bam"
                }
            ],
            "id": "#mark_duplicates_and_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Sambamba: merge",
            "baseCommand": [
                "/bin/bash",
                "merge.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bam-merge:0.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "merge.sh",
                            "entry": "#!/bin/bash\nset -o pipefail\nset -o errexit\nset -o nounset\n\nSORTED=false\n\nwhile getopts \"t:n:s:\" opt; do\n    case \"$opt\" in\n        t)\n            NTHREADS=\"$OPTARG\"\n            ;;\n        n)\n            OUTFILENAME=\"$OPTARG\"\n            ;;\n        s)\n            SORTED=true\n            ;;\n    esac\ndone\n\nBAMS=(\"${@:$OPTIND}\")\nNUM_BAMS=${#BAMS[@]}\n\n#if there is only one bam, just copy it and index it\nif [[ $NUM_BAMS -eq 1 ]]; then\n    cp \"$BAMS\" \"$OUTFILENAME\";\nelse\n    if [[ $SORTED == \"true\" ]];then\n        /usr/bin/sambamba merge -t \"$NTHREADS\" \"$OUTFILENAME\" \"${BAMS[@]}\"\n    else #unsorted bams, use picard\n        args=(OUTPUT=\"$OUTFILENAME\" ASSUME_SORTED=true USE_THREADING=true SORT_ORDER=unsorted VALIDATION_STRINGENCY=LENIENT)\n        for i in \"${BAMS[@]}\";do\n          args+=(\"INPUT=$i\")\n        done\n        java -jar -Xmx6g /opt/picard/picard.jar MergeSamFiles \"${args[@]}\"\n    fi\nfi\nif [[ $SORTED == \"true\" ]];then\n  /usr/bin/sambamba index \"$OUTFILENAME\"\nfi\n"
                        }
                    ]
                }
            ],
            "arguments": [
                "-t",
                "$(runtime.cores)"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#merge_bams.cwl/bams"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "merged.bam",
                    "inputBinding": {
                        "prefix": "-n",
                        "position": 1
                    },
                    "id": "#merge_bams.cwl/name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": "false",
                    "inputBinding": {
                        "prefix": "-s",
                        "position": 2
                    },
                    "id": "#merge_bams.cwl/sorted"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.name)"
                    },
                    "id": "#merge_bams.cwl/merged_bam"
                }
            ],
            "id": "#merge_bams.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "sort BAM by name",
            "baseCommand": [
                "/usr/bin/sambamba",
                "sort"
            ],
            "arguments": [
                "-t",
                {
                    "valueFrom": "$(runtime.cores)"
                },
                "-m",
                "22G",
                "-n",
                "-o",
                {
                    "valueFrom": "$(inputs.bam.nameroot).NameSorted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 26000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/sambamba-cwl:0.6.4"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#name_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).NameSorted.bam"
                    },
                    "id": "#name_sort.cwl/name_sorted_bam"
                }
            ],
            "id": "#name_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "align with bwa_mem and tag",
            "doc": "Due to workflow runner limitations, use sequence_align_and_tag_adapter.cwl subworkflow to call this",
            "baseCommand": [
                "/bin/bash",
                "sequence_alignment_helper.sh"
            ],
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        },
                        {
                            "$import": "#trimming_options.yml/trimming_options"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 20000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/alignment_helper-cwl:1.1.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "sequence_alignment_helper.sh",
                            "entry": "set -o pipefail\nset -o errexit\nset -o nounset\n\nRUN_TRIMMING=\"false\"\n\nwhile getopts \"b:?1:?2:?g:r:n:t:?o:?\" opt; do\n    case \"$opt\" in\n        b)\n            MODE=bam\n            BAM=\"$OPTARG\"\n            ;;\n        1)\n            MODE=fastq\n            FASTQ1=\"$OPTARG\"\n            ;;\n        2)  \n            MODE=fastq\n            FASTQ2=\"$OPTARG\"\n            ;;\n        g)\n            READGROUP=\"$OPTARG\"\n            ;;\n        r)\n            REFERENCE=\"$OPTARG\"\n            ;;\n        n)\n            NTHREADS=\"$OPTARG\"\n            ;;\n        t)\n            RUN_TRIMMING=\"true\"\n            TRIMMING_ADAPTERS=\"$OPTARG\"\n            ;;\n        o)\n            RUN_TRIMMING=\"true\"\n            TRIMMING_ADAPTER_MIN_OVERLAP=\"$OPTARG\"\n            ;;\n    esac\ndone\n\nif [[ \"$MODE\" == 'fastq' ]]; then\n    if [[ \"$RUN_TRIMMING\" == 'false' ]]; then\n        /usr/local/bin/bwa mem -K 100000000 -t \"$NTHREADS\" -Y -R \"$READGROUP\" \"$REFERENCE\" \"$FASTQ1\" \"$FASTQ2\" | /usr/local/bin/samblaster -a --addMateTags | /opt/samtools/bin/samtools view -b -S /dev/stdin\n    else\n        /opt/flexbar/flexbar --adapters \"$TRIMMING_ADAPTERS\" --reads \"$FASTQ1\" --reads2 \"$FASTQ2\" --adapter-trim-end LTAIL --adapter-min-overlap \"$TRIMMING_ADAPTER_MIN_OVERLAP\" --adapter-error-rate 0.1 --max-uncalled 300 --stdout-reads \\\n          | /usr/local/bin/bwa mem -K 100000000 -t \"$NTHREADS\" -Y -p -R \"$READGROUP\" \"$REFERENCE\" /dev/stdin | /usr/local/bin/samblaster -a --addMateTags | /opt/samtools/bin/samtools view -b -S /dev/stdin\n    fi\nfi\nif [[ \"$MODE\" == 'bam' ]]; then\n    if [[ \"$RUN_TRIMMING\" == 'false' ]]; then\n        /usr/bin/java -Xmx4g -jar /opt/picard/picard.jar SamToFastq I=\"$BAM\" INTERLEAVE=true INCLUDE_NON_PF_READS=true FASTQ=/dev/stdout | /usr/local/bin/bwa mem -K 100000000 -t \"$NTHREADS\" -Y -p -R \"$READGROUP\" \"$REFERENCE\" /dev/stdin | /usr/local/bin/samblaster -a --addMateTags | /opt/samtools/bin/samtools view -b -S /dev/stdin\n    else\n       /usr/bin/java -Xmx4g -jar /opt/picard/picard.jar SamToFastq I=\"$BAM\" INTERLEAVE=true INCLUDE_NON_PF_READS=true FASTQ=/dev/stdout \\\n         | /opt/flexbar/flexbar --adapters \"$TRIMMING_ADAPTERS\" --reads - --interleaved --adapter-trim-end LTAIL --adapter-min-overlap \"$TRIMMING_ADAPTER_MIN_OVERLAP\" --adapter-error-rate 0.1 --max-uncalled 300 --stdout-reads \\\n         | /usr/local/bin/bwa mem -K 100000000 -t \"$NTHREADS\" -Y -p -R \"$READGROUP\" \"$REFERENCE\" /dev/stdin | /usr/local/bin/samblaster -a --addMateTags | /opt/samtools/bin/samtools view -b -S /dev/stdin\n    fi\nfi\n"
                        }
                    ]
                }
            ],
            "stdout": "refAlign.bam",
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": 5,
                    "prefix": "-n"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "id": "#sequence_align_and_tag.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-1"
                    },
                    "id": "#sequence_align_and_tag.cwl/fastq1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-2"
                    },
                    "id": "#sequence_align_and_tag.cwl/fastq2"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "id": "#sequence_align_and_tag.cwl/readgroup"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-r"
                    },
                    "doc": "bwa-indexed reference file",
                    "id": "#sequence_align_and_tag.cwl/reference"
                },
                {
                    "type": [
                        "#trimming_options.yml/trimming_options",
                        "null"
                    ],
                    "inputBinding": {
                        "valueFrom": "$( ['-t', self.adapters.path, '-o', self.min_overlap] )"
                    },
                    "id": "#sequence_align_and_tag.cwl/trimming"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sequence_align_and_tag.cwl/aligned_bam",
                    "outputBinding": {
                        "glob": "refAlign.bam"
                    }
                }
            ],
            "id": "#sequence_align_and_tag.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
